@@ -83,10 +83,10 @@ class CertClass (qt.QWidget):
         self.setAttribute(qt.Qt.WA_DeleteOnClose)
 
         self.setFixedSize(self.sizeHint().width(), self.sizeHint().height())
-        self.move(window.geometry().x() + window.geometry().width() / 2 \
-                  - self.size().width() / 2, \
-                  window.geometry().y() + window.geometry().height() / 2 \
-                  - self.size().height() / 2 - 50)  
+        self.move(window.geometry().x() + window.geometry().width() // 2 \
+                  - self.size().width() // 2, \
+                  window.geometry().y() + window.geometry().height() // 2 \
+                  - self.size().height() // 2 - 50)  
 
         self.setWindowTitle (_('Certificates'))
         self.setWindowIcon (get_icon("view-certificate"))
