@@ -14,13 +14,11 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
 import dbus
 import dbus.service
 import dbus.mainloop.glib
 
-from calculate.consolegui import qt
+from .. import qt
 import time, sys
 import calculate.contrib
 from suds import MethodNotFound
@@ -35,7 +33,7 @@ from .more import get_sid, get_view_params, _print, get_icon, get_system_rgb, \
     dpivalue
     
 from .MainClass import ApiClient
-from calculate.consolegui.datavars import DataVarsGui
+from ..datavars import DataVarsGui
 from .pid_information import client_pid_info
 #from calculate.lib.cl_lang import setLocalTranslate
 #setLocalTranslate('console_gui',sys.modules[__name__])
@@ -133,7 +131,7 @@ class SelectedMethodWgt(qt.QWidget):
             size = self.config.get('gui', 'size')
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
-        tup_size = map(lambda x: int(x), size.split(','))
+        tup_size = [int(x) for x in size.split(',')]
         self.resize(tup_size[0], tup_size[1])
         return True
 
@@ -285,7 +283,7 @@ class ToolTabWidget(qt.QTabWidget):
         if args:
             if args.lang:
                 self.lang = args.lang
-
+        
         self.current_icon = None
         self.setContentsMargins(0,0,0,0)
         self.init_variables()
@@ -568,7 +566,7 @@ class ToolTabWidget(qt.QTabWidget):
             size = self.config.get('gui', 'size')
         except (ConfigParser.NoOptionError, ConfigParser.NoSectionError):
             return False
-        tup_size = list(map(lambda x: int(x), size.split(',')))
+        tup_size = [int(x) for x in size.split(',')]
         self.resize(tup_size[0], tup_size[1])
         return True
 
