@@ -157,10 +157,10 @@ class FrameConnection(qt.QWidget):
         self.setLayout(grid)
         
         self.setFixedSize(dpivalue(300), dpivalue(160))
-        self.move(window.geometry().x() + window.geometry().width() / 2 \
-                  - self.sizeHint().width() / 2, \
-                  window.geometry().y() + window.geometry().height() / 2 \
-                  - self.sizeHint().height() / 2)
+        self.move(window.geometry().x() + window.geometry().width() // 2 \
+                  - self.sizeHint().width() // 2, \
+                  window.geometry().y() + window.geometry().height() // 2 \
+                  - self.sizeHint().height() // 2)
         self.setWindowTitle(_('Connection'))
         self.setWindowIcon(get_icon("network-connect"))
         
